Learn R Programming

vardpoor (version 0.2.0.8.1)

linrmpg: Linearization of the relative median at-risk-of-poverty gap

Description

Estimate the relative median at-risk-of-poverty gap, which is defined as the relative difference between the median equivalized disposable income of persons below the at-risk-of-poverty threshold and the at-risk-of-poverty threshold itself (expressed as a percentage of the at-risk-of-poverty threshold) and its linearization.

Usage

linrmpg(inc, id, weight=NULL, sort=NULL, Dom=NULL,
          period=NULL, dataset = NULL, percentage=60,
          order_quant=50, na.rm=FALSE, var_name="lin_rmpg")

Arguments

inc
either a numeric vector, 1 column data.frame, matrix, data.table giving the equivalized disposable income, or (if dataset is not NULL) a character string, an integer or a logical vector (length is the same as 'dataset
id
optional; either 1 column data.frame, matrix, data.table with column names giving the personal IDs, or (if dataset is not NULL) a character string, an integer or a logical vector (length is the same as 'dataset' colum
weight
optional; either a numeric vector, 1 column data.frame, matrix, data.table giving the personal sample weights, or (if dataset is not NULL) a character string, an integer or a logical vector (length is the same as 'dat
sort
optional; either a numeric vector, 1 column data.frame, matrix, data.table giving the personal IDs to be used as tie-breakers for sorting, or (if dataset is not NULL) a character string, an integer or a logical vector
Dom
optional; either a data.frame, matrix, data.table with column names giving different domains, or (if dataset is not NULL) character strings, integers or a logical vectors (length is the same as 'dataset' column count)
period
optional; either a data.frame, matrix, data.table with column names giving different periods, or (if dataset is not NULL) character strings, integers or a logical vectors (length is the same as 'dataset' column coun
dataset
an optional; name of the individual dataset data.frame.
percentage
a numeric value in $[0,100]$ giving the percentage of the income quantile to be used for the at-risk-of-poverty threshold (see linarpt).
order_quant
a numeric value in $[0,100]$ giving the order of the income quintale (in percentage) to be used for the at-risk-of-poverty threshold (see linarpt).
na.rm
a logical indicating whether missing values should be removed.
var_name
a character string specifying the name of the linearized variable.

Value

  • The function returns two values:
  • valuea data.frame containing the estimate(s) the relative median at-risk-of-poverty gap (in percentage) by domain, or (if Dom is NULL) totals, using Eurostat definition.
  • lina data.frame containing the values of linearized variables of the relative median at-risk-of-poverty gap (in precentage) by domains or (if Dom is NULL) totals.

References

Working group on Statistics on Income and Living Conditions (2004) Common cross-sectional EU indicators based on EU-SILC; the gender pay gap. EU-SILC 131-rev/04, Eurostat. Guillaume Osier (2009). Variance estimation for complex indicators of poverty and inequality. Journal of the European Survey Research Association, Vol.3, No.3, pp. 167-195, ISSN 1864-3361, URL https://ojs.ub.uni-konstanz.de/srm/article/view/369. Deville, J. C. (1999). Variance estimation for complex statistics and estimators: linearization and residual techniques. Survey Methodology, 25, 193-203, URL http://www5.statcan.gc.ca/bsolc/olc-cel/olc-cel?lang=eng&catno=12-001-X19990024882.

See Also

linarpt, linarpr, linpoormed, varpoord, var_srs

Examples

Run this code
data(eusilc)
dati=data.frame(1:nrow(eusilc),eusilc)
colnames(dati)[1] <- "IDd"
d<-linrmpg("eqIncome", id="IDd", weight = "rb050", Dom = NULL,
            dataset = dati, percentage = 60, order_quant=50, na.rm = FALSE)
dd<-linrmpg("eqIncome", id="IDd", weight = "rb050", Dom = "db040",
             dataset = dati, percentage = 60, order_quant=50, na.rm = FALSE)
d$value
dd$value
d$threshold

Run the code above in your browser using DataLab