linpoormed(inc, id, weight=NULL, sort=NULL, Dom=NULL,
period=NULL, dataset = NULL, percentage=60,
order_quant=50, na.rm=FALSE, var_name="lin_poormed")dataset is not NULL) a
character string, an integer or a logical vector (length
is the same as 'datasetdataset is not NULL) a character
string, an integer or a logical vector (length is the
same as 'dataset' columdataset is not NULL) a
character string, an integer or a logical vector (length
is the same as 'datdataset
is not NULL) a character string, an integer or a
logical vectordataset is not NULL) character strings,
integers or a logical vectors (length is the same as
'dataset' columndataset is not NULL) character strings,
integers or a logical vectors (length is the same as
'dataset' column coundata.frame.linarpt).linarpt).data.frame containing the estimate(s) the
gini coeffients (in percentage) by domain, or (if Dom
is NULL) totals, using Eurostat definition definition.data.frame containing the values of
linearized variables of the GINI coefficient (in precentage)
by domains or (if Dom is NULL) totals.linarpt, varpoord, var_srsdata(eusilc)
dati=data.frame(1:nrow(eusilc),eusilc)
colnames(dati)[1] <- "IDd"
d<-linpoormed("eqIncome", id="IDd", weight = "rb050", Dom = NULL,
dataset = dati, percentage = 60, order_quant=50, na.rm = FALSE)
dd<-linpoormed("eqIncome", id="IDd", weight = "rb050", Dom = "db040",
dataset = dati, percentage = 60, order_quant=50, na.rm = FALSE)Run the code above in your browser using DataLab