- Y
Study variable (for example equalized disposable income). One dimensional object convertible to one-column data.table or variable name as character, column number.
- id
Optional variable for unit ID codes. One dimensional object convertible to one-column data.table or variable name as character, column number.
- weight
Optional weight variable. One dimensional object convertible to one-column data.table or variable name as character, column number.
- sort
Optional variable to be used as tie-breaker for sorting. One dimensional object convertible to one-column data.table or variable name as character, column number.
- Dom
Optional variables used to define population domains. If supplied, linearization of the median income of persons below a poverty threshold is done for each domain. An object convertible to data.table or variable names as character vector, column numbers.
- period
Optional variable for survey period. If supplied, linearization of the median income of persons below a poverty threshold is done for each time period. Object convertible to data.table or variable names as character, column numbers.
- dataset
Optional survey data object convertible to data.table.
- percentage
A numeric value in range \([0,100]\) for \(p\) in the formula for poverty threshold computation: $$\frac{p}{100} \cdot Z_{\frac{\alpha}{100}}.$$ For example, to compute poverty threshold equal to 60% of some income quantile, \(p\) should be set equal to 60.
- order_quant
A numeric value in range \([0,100]\) for \(\alpha\) in the formula for poverty threshold computation: $$\frac{p}{100} \cdot Z_{\frac{\alpha}{100}}.$$. For example, to compute poverty threshold equal to some percentage of median income, \(\alpha\) should be set equal to 50.
- var_name
A character specifying the name of the linearized variable.
- checking
Optional variable if this variable is TRUE, then function checks data preparation errors, otherwise not checked. This variable by default is TRUE.