linrmpg(inc, id, weight=NULL, sort=NULL, Dom=NULL,
period=NULL, dataset = NULL, percentage=60,
order_quant=50, na.rm=FALSE, var_name="lin_rmpg")dataset is not NULL)
a character string, an integer or a logical vector
(length is the same as 'datasetdataset is not NULL) a character string,
an integer or a logical vector (length is the same as
'dataset' columdataset is not NULL) a
character string, an integer or a logical vector (length
is the same as 'datdataset
is not NULL) a character string, an integer or a
logical vectordataset is not NULL) character strings,
integers or a logical vectors (length is the same as
'dataset' column count)dataset is not NULL) character strings,
integers or a logical vectors (length is the same as
'dataset' column coundata.frame.linarpt).linarpt).data.frame containing the estimate(s)
the relative median at-risk-of-poverty gap (in percentage)
by domain, or (if Dom is NULL) totals, using
Eurostat definition.data.frame containing the values of
linearized variables of the relative median at-risk-of-poverty
gap (in precentage) by domains or (if Dom is NULL)
totals.linarpt, linarpr, linpoormed,
varpoord, var_srsdata(eusilc)
dati=data.frame(1:nrow(eusilc),eusilc)
colnames(dati)[1] <- "IDd"
d<-linrmpg("eqIncome", id="IDd", weight = "rb050", Dom = NULL,
dataset = dati, percentage = 60, order_quant=50, na.rm = FALSE)
dd<-linrmpg("eqIncome", id="IDd", weight = "rb050", Dom = "db040",
dataset = dati, percentage = 60, order_quant=50, na.rm = FALSE)
d$value
dd$value
d$thresholdRun the code above in your browser using DataLab