var_srs: The estimation of the simple random sampling.
Description
Computes the estimation of the simple random sampling.
Usage
var_srs(Y, w)
Arguments
Y
data.frame, matrix, data.table of the variable of interest; its length is equal to n, the sample size.
w
vector or 1 column data.frame, matrix, data.table of the weights; its length is equal to n, the sample size.
Value
a data.frame containing the values of the variance estimation of the simple random sampling by period.
Details
The function implements the following estimator:
References
Pascal Ardilly and Guillaume Osier (2007). Cross-sectional
variance estimation for the French Labour Force Survey
Journal of the European Survey Research Association,
Vol.1 , No.2 , pp. 75-83, ISSN 1864-3361,
URL https://ojs.ub.uni-konstanz.de/srm/article/viewFile/77/55.