varpoord(inc, w_final, income_thres = NULL, wght_thres = NULL,
ID_household, id = NULL, H, PSU, N_h, fh_zero = FALSE,
PSU_level=TRUE, sort = NULL, Dom = NULL, period = NULL,
gender = NULL, dataset = NULL, X = NULL, periodX = NULL,
X_ID_household = NULL, ind_gr = NULL, g = NULL, datasetX = NULL,
q, percentage = 60, order_quant = 50, alpha = 20,
confidence = 0.95, outp_lin = FALSE, outp_res = FALSE,
na.rm = FALSE, several.ok = FALSE, type = "lin_rmpg")dataset is not NULL) a
character string, an integer or a logical vector (length
is the same as 'datasetdataset is not NULL) a
character string, an integer or a logical vector (length
is the same as 'dadataset is not
NULL) a character string, an dataset is not NULL) a
character string, an integedataset is not NULL) a character string,
an integer or a logical vector (length is the same as
'dataset' column count)dataset is not NULL) a character string,
an integer or a logical vector (length is the same as
'dataset' columdataset is not NULL) a character string,
an integer or a logical vector (length is the same as 'datasetdataset is not NULL)
a character string, an integer or a logical vector (length is the
same as 'dataset' column count) specifying the codataset
is not NULL) a character string, an integer or a
logical vectordataset is
not NULL) character strings, integers or a logical vectors
(length is the same as 'dataset' column count) spdataset is not NULL) character strings,
integers or a logical vectors (length is the same as
'dataset' column coundataset is not NULL) a character string, an
integer or a logical vector (length is the same as 'dataset'
column count) specifying the corresponding column of
datasetdata.frame.datasetX is not NULL)
character strings, integers or a logical vectors (length is the
same as 'dataset' column count) specifying the codatasetX is not NULL) character strings,
integers or a logical vectors (length is the same as
'dataset'datasetX is not NULL) a character string,
an integer or a logical vector (length is the same as
datasetX is not
NULL) a character string, an integer or a logical vector
datasetX
is not NULL) a character string, an integer or a logical
vector (length is the same as 'dataset' column codata.frame.datasetX is not NULL) a
character string, an integer or a logical vector (llinarpt).linarpt).TRUE linearized
values will be printed outTRUE estimated residuals
of calibration will be printed outtype should be
allowed to have more than one.data.frame containing the estimation(s)
by domain, or (if Dom is NULL) totals.matrix containing the values of the
variance estimation by domains or (if Dom is NULL)
totals.matrix containing the values of the
standart error by domains or (if Dom is NULL)
totals.data.frame containing the values of the
relative standart error (coefficient of variation) by domains
or (if Dom is NULL) totals in percentage.data.frame containing the values of the
relative standart error (coefficient of variation) by domains
or (if Dom is NULL) totals.matrix containing
the values of the absolute margin of error by domains or
(if Dom is NULL) totals.matrix containing
the values of the relative margin of error by domains or
(if Dom is NULL) totals.data.frame containing the values of
the confidence interval lower bound by domains or (if Dom
is NULL) totals.data.frame containing the values of
the confidence interval upper bound by domains or (if Dom
is NULL) totals.matrix containing the values of
the variance estimation of HT estimator under SRS by domains
or (if Dom is NULL) totals.matrix containing the values of the
variance estimation of HT estimator under HT estimator under
current design by domains or (if Dom is NULL) totals.matrix containing the values of
the variance estimation of calibrated estimator under SRS
by domains or (if Dom is NULL) totals.matrix containing the values of
the estimation of the design effect of sample design by
domains or (if Dom is NULL) totals.matrix containing the values of
the estimation of the design effect of estimator by domains
or (if Dom is NULL) totals.matrix containing the values of
the estimation of the overall design effect of sample
design and estimator by domains or (if Dom is
NULL) totals.data.table containing the
linearized values with ID_household and id.data.table containing the estimated
residuals of calibration with id and PSU.data.frame containing all previosly definited
values together by domains or (if Dom is NULL) totals.vardom, vardomh, linarptdata(eusilc)
dataset <- data.frame(1:nrow(eusilc),eusilc)
colnames(dataset)[1] <- "IDd"
aa<-varpoord("eqIncome", "rb050", income_thres = NULL,
wght_thres = NULL, ID_household = "db030",
id = NULL, H="db040",
PSU="rb030", N_h=NULL, sort = NULL,
Dom = "db040", gender = NULL, X = NULL,
X_ID_household = NULL,
g = NULL,
datasetX = NULL,
q = rep(1, if (is.null(datasetX))
nrow(as.data.frame(H)) else nrow(datasetX)),
dataset = dataset, percentage=60, order_quant=50,
alpha = 20, confidence = .95, outp_lin = TRUE,
outp_res = TRUE, na.rm=FALSE,
several.ok=FALSE, type="lingini")
aa$lin_out[20:40]
aa$res_out[20:40]Run the code above in your browser using DataLab